const express = require('express');
const router = express.Router();
const db = require('../utils/db');
const auth = require('../middleware/auth');
const checkPermission = require('../middleware/checkPermission');

// 获取所有标签
router.get('/', async (req, res) => {
  try {
    const [tags] = await db.query('SELECT * FROM game_tag_master ORDER BY name');
    res.json(tags);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
});

// 添加标签
router.post('/', auth, checkPermission('tag:manage'), async (req, res) => {
  try {
    const { name, description } = req.body;
    
    if (!name) {
      return res.status(400).json({ message: '标签名称不能为空' });
    }

    const [result] = await db.query(
      'INSERT INTO game_tag_master (name, description) VALUES (?, ?)',
      [name, description || '']
    );

    res.status(201).json({ 
      message: '标签添加成功',
      id: result.insertId 
    });
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
});

// 更新标签
router.put('/:id', auth, checkPermission('tag:manage'), async (req, res) => {
  try {
    const { name, description } = req.body;
    
    if (!name) {
      return res.status(400).json({ message: '标签名称不能为空' });
    }

    await db.query(
      'UPDATE game_tag_master SET name = ?, description = ? WHERE id = ?',
      [name, description || '', req.params.id]
    );

    res.json({ message: '标签更新成功' });
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
});

// 删除标签
router.delete('/:id', auth, checkPermission('tag:manage'), async (req, res) => {
  try {
    await db.query('DELETE FROM game_tag_master WHERE id = ?', [req.params.id]);
    res.json({ message: '标签删除成功' });
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
});

module.exports = router; 