require('dotenv').config();
const mysql = require('mysql2/promise');

async function testConnection() {
  console.log('Testing database connection...');
  console.log('Connection details:', {
    host: process.env.DB_HOST,
    user: process.env.DB_USER,
    database: process.env.DB_DATABASE
  });

  try {
    const connection = await mysql.createConnection({
      host: process.env.DB_HOST,
      user: process.env.DB_USER,
      password: process.env.DB_PASSWORD,
      database: process.env.DB_DATABASE
    });

    console.log('Connection established successfully');

    // 测试查询
    const [rows] = await connection.query('SELECT 1 as test');
    console.log('Test query result:', rows);

    // 测试admins表
    const [admins] = await connection.query('SELECT COUNT(*) as count FROM admins');
    console.log('Admins count:', admins[0].count);

    await connection.end();
    console.log('Connection closed');
  } catch (error) {
    console.error('Connection test failed:', error);
    process.exit(1);
  }
}

testConnection(); 