import { createRouter, createWebHistory } from 'vue-router';
import AdminLogin from '../views/admin/Login.vue';
import AdminLayout from '../views/admin/Layout.vue';
import Dashboard from '../views/admin/Dashboard.vue';
import GameManagement from '../views/admin/GameManagement.vue';
import MediaManagement from '../views/admin/MediaManagement.vue';
import CategoryManagement from '../views/admin/CategoryManagement.vue';
import UserManagement from '../views/admin/UserManagement.vue';
import axios from 'axios';

const routes = [
  {
    path: '/admin/login',
    name: 'AdminLogin',
    component: AdminLogin,
    meta: { requiresAuth: false }
  },
  {
    path: '/admin',
    component: AdminLayout,
    meta: { requiresAuth: true },
    children: [
      {
        path: '',
        name: 'Dashboard',
        component: Dashboard
      },
      {
        path: 'games',
        name: 'GameManagement',
        component: GameManagement
      },
      {
        path: 'media',
        name: 'MediaManagement',
        component: MediaManagement
      },
      {
        path: 'categories',
        name: 'CategoryManagement',
        component: CategoryManagement
      },
      {
        path: 'users',
        name: 'UserManagement',
        component: UserManagement,
        meta: { requiresPermission: 'user:manage' }
      }
    ]
  }
];

const router = createRouter({
  history: createWebHistory(),
  routes
});

// 路由守卫
router.beforeEach(async (to, from, next) => {
  const token = localStorage.getItem('admin_token');
  
  if (to.matched.some(record => record.meta.requiresAuth)) {
    if (!token) {
      next('/admin/login');
      return;
    }
    
    // 检查权限
    if (to.meta.requiresPermission) {
      try {
        const response = await axios.get('http://localhost:3000/api/admins/me', {
          headers: { Authorization: `Bearer ${token}` }
        });
        
        const user = response.data;
        if (user.role !== 'superadmin' && 
            !user.permissions.includes(to.meta.requiresPermission)) {
          next('/admin'); // 重定向到仪表盘
          return;
        }
      } catch (error) {
        next('/admin/login');
        return;
      }
    }
    
    next();
  } else {
    next();
  }
});

export default router; 