import axios from 'axios'

// 设置基础URL
axios.defaults.baseURL = process.env.VUE_APP_API_URL || 'http://localhost:3000'

// 添加请求拦截器用于调试
axios.interceptors.request.use(config => {
  console.log('API Request:', {
    url: config.url,
    method: config.method,
    data: config.data
  });
  return config;
});

// 添加响应拦截器用于调试
axios.interceptors.response.use(
  response => {
    console.log('API Response:', {
      url: response.config.url,
      status: response.status,
      data: response.data
    });
    return response;
  },
  error => {
    console.error('API Error:', {
      url: error.config?.url,
      status: error.response?.status,
      data: error.response?.data
    });
    return Promise.reject(error);
  }
);

export const login = async (username, password) => {
  console.log('API: Sending login request');
  try {
    const response = await axios.post('/api/admin/login', { username, password })
    console.log('API: Login response:', response.data);
    return response.data
  } catch (error) {
    console.error('API: Login error:', error);
    throw error
  }
}

export const register = async ({ username, password, email }) => {
  console.log('API: Sending register request');
  try {
    const response = await axios.post('/api/admin/register', {
      username,
      password,
      email
    })
    console.log('API: Register response:', response.data);
    return response.data
  } catch (error) {
    console.error('API: Register error:', error);
    throw error
  }
}

export const getGames = async () => {
  const response = await axios.get('/api/games')
  return response.data
}

export const getCategories = async () => {
  const response = await axios.get('/api/categories')
  return response.data
}

export const getAdmins = async () => {
  const response = await axios.get('/api/admins')
  return response.data
}

export const createAdmin = async (data) => {
  const response = await axios.post('/api/admins', data)
  return response.data
}

export const updateAdmin = async (id, data) => {
  const response = await axios.put(`/api/admins/${id}`, data)
  return response.data
}

export const deleteAdmin = async (id) => {
  const response = await axios.delete(`/api/admins/${id}`)
  return response.data
}

export const getStats = async () => {
  const response = await axios.get('/api/stats')
  return response.data
} 